@@ -137,11 +137,7 @@ xthread_t (*_Xthread_self_fn)(void) = NULL;
 #define ECHECK(err) (errno == err)
 #define ESET(val)
 #else
-#ifdef ISC
-#define ECHECK(err) ((errno == err) || ETEST())
-#else
 #define ECHECK(err) (errno == err)
-#endif
 #define ESET(val) errno = val
 #endif
 #endif
@@ -299,7 +295,7 @@ _XWaitForWritable(
 	    nfound = Select (dpy->fd + 1, &r_mask, &w_mask, NULL, NULL);
 #endif
 	    InternalLockDisplay(dpy, cv != NULL);
-	    if (nfound < 0 && !ECHECK(EINTR))
+	    if (nfound < 0 && !(ECHECK(EINTR) || ETEST()))
 		_XIOError(dpy);
 	} while (nfound <= 0);
 
@@ -511,7 +507,7 @@ _XWaitForReadable(
 	result = Select(highest_fd + 1, &r_mask, NULL, NULL, NULL);
 #endif
 	InternalLockDisplay(dpy, dpy->flags & XlibDisplayReply);
-	if (result == -1 && !ECHECK(EINTR)) _XIOError(dpy);
+	if (result == -1 && !(ECHECK(EINTR) || ETEST())) _XIOError(dpy);
 	if (result <= 0)
 	    continue;
 #ifdef USE_POLL
@@ -842,7 +838,7 @@ _XEventsQueued(
 		    if (!pend)
 			pend = SIZEOF(xReply);
 		}
-		else if (result < 0 && !ECHECK(EINTR))
+		else if (result < 0 && !(ECHECK(EINTR) || ETEST()))
 		    _XIOError(dpy);
 	    }
 	}
@@ -2881,10 +2877,7 @@ int _XDefaultError(
 }
 
 /*ARGSUSED*/
-Bool _XDefaultWireError(display, he, we)
-    Display     *display;
-    XErrorEvent *he;
-    xError      *we;
+Bool _XDefaultWireError(Display *display, XErrorEvent *he, xError *we)
 {
     return True;
 }
@@ -3216,7 +3209,7 @@ static doData32(
 void _XData32(
     Display *dpy,
     long *data,
-    unsigned len,
+    unsigned len)
 {
     char packbuffer[PACKBUFFERSIZE];
     unsigned nunits = PACKBUFFERSIZE >> 2;
@@ -3280,9 +3273,7 @@ int _XGetHostname (
  * _XScreenOfWindow - get the Screen of a given window
  */
 
-Screen *_XScreenOfWindow (dpy, w)
-    Display *dpy;
-    Window w;
+Screen *_XScreenOfWindow(Display *dpy, Window w)
 {
     register int i;
     Window root;
@@ -3291,7 +3282,7 @@ Screen *_XScreenOfWindow (dpy, w)
 
     if (XGetGeometry (dpy, w, &root, &x, &y, &width, &height,
 		      &bw, &depth) == False) {
-	return None;
+	return NULL;
     }
     for (i = 0; i < ScreenCount (dpy); i++) {	/* find root from list */
 	if (root == RootWindow (dpy, i)) {
